@@ -25,18 +25,25 @@ status_flags = NamedTuple(
         ('package_source_rebuild', str),
         ('package_source_rebuild_clean', str),
         ('package_build_failed', str),
+        ('image_build_failed', str),
         ('package_build_succeeded', str),
+        ('image_build_succeeded', str),
         ('package_build_running', str),
         ('buildroot_setup_failed', str),
         ('buildroot_setup_succeeded', str),
         ('package_request_accepted', str),
         ('incompatible_build_arch', str),
         ('reset_running_build', str),
-        ('package_not_existing', str),
-        ('package_metadata_not_existing', str),
+        ('project_not_existing', str),
+        ('project_metadata_not_existing', str),
         ('package_target_not_configured', str),
+        ('image_target_not_configured', str),
+        ('image_source_rebuild', str),
+        ('image_rebuild', str),
+        ('image_request_accepted', str),
         ('invalid_metadata', str),
-        ('package_local', str)
+        ('package_local', str),
+        ('image_local', str)
     ]
 )
 
@@ -62,9 +69,9 @@ class Defaults:
         return 'cloud_builder.kiwi'
 
     @staticmethod
-    def get_package_request_queue_name() -> str:
+    def get_build_request_queue_name() -> str:
         """
-        Return name of message queue used for sending
+        Return default name of message queue used for sending
         package build requests.
 
         Queue is a shared queue:
@@ -74,7 +81,7 @@ class Defaults:
         readers. In kafka this done by assigning as many partitions
         as there are potential readers
         """
-        return 'cb-package-request'
+        return 'cb-build-request'
 
     @staticmethod
     def get_response_queue_name() -> str:
@@ -135,10 +142,9 @@ class Defaults:
         return '/var/log/cloud_builder.log'
 
     @staticmethod
-    def get_runner_package_root() -> str:
+    def get_runner_root() -> str:
         """
-        Return root path name to construct package build roots
-        for building the packages on the runner
+        Return root path name to build packages/images
 
         :return: directory path name
 
@@ -172,18 +178,25 @@ class Defaults:
             package_source_rebuild='package rebuild due to source change',
             package_source_rebuild_clean='package rebuild on new buildroot due to source change',
             package_build_failed='package build failed',
+            image_build_failed='image build failed',
             package_build_succeeded='package build succeeded',
+            image_build_succeeded='image build succeeded',
             package_build_running='package build running',
             buildroot_setup_failed='build root setup failed',
             buildroot_setup_succeeded='build root setup succeeded',
             package_request_accepted='package request accepted',
             incompatible_build_arch='incompatible build arch',
             reset_running_build='reset running build',
-            package_not_existing='package does not exist',
-            package_metadata_not_existing='package metadata does not exist',
+            project_not_existing='project does not exist',
+            project_metadata_not_existing='project metadata does not exist',
             invalid_metadata='invalid package metadata',
             package_target_not_configured='package target not configured',
-            package_local='package build on localhost requested'
+            image_target_not_configured='image target not configured',
+            image_source_rebuild='image rebuild due to source change',
+            image_rebuild='image rebuild requested',
+            image_request_accepted='image request accepted',
+            package_local='package build on localhost requested',
+            image_local='image build on localhost requested'
         )
 
     @staticmethod
